@@ -17,11 +17,11 @@ MySQL::Util - Utility functions for working with MySQL.
 
 =head1 VERSION
 
-Version 0.26
+Version 0.27
 
 =cut
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 =head1 SYNOPSIS
 
@@ -1339,7 +1339,7 @@ sub get_tables {
 	my $dbh = $self->_dbh;
 
 	my $tables = undef;
-	my $sth    = $dbh->prepare("show tables");
+	my $sth    = $dbh->prepare("show full tables where Table_Type = 'BASE TABLE'");
 	$sth->execute;
 
 	while ( my ($table) = $sth->fetchrow_array ) {
